
Welcome to the 2018 Crops in Silico Hackathon!
##############################################

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   setup
   intro
   transformation
   connection